@@ -1,6 +1,6 @@
 package Facebook::Graph::AccessToken;
 BEGIN {
-  $Facebook::Graph::AccessToken::VERSION = '0.0200';
+  $Facebook::Graph::AccessToken::VERSION = '0.0201';
 }
 
 use Moose;
@@ -58,14 +58,34 @@ Facebook::Graph::AccessToken - Acquire an access token from Facebook.
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
+
+=head1 SYNOPSIS
+
+ my $fb = Facebook::Graph->new(
+    secret      => $facebook_application_secret,
+    app_id      => $facebook_application_id,
+    postback    => 'https://www.yourapplication.com/facebook/postback',
+ );
+ my $token_response_object = $fb->request_access_token($code_from_authorize_postback);
+
+ my $token_string = $token_response_object->token;
+ my $token_expires_epoch = $token_response_object->expires;
+
+=head1 DESCRIPTION
+
+Allows you to request an access token from Facebook so you can make privileged requests on the Graph API.
 
 =head1 METHODS
 
 =head2 uri_as_string ()
 
+Returns the URI that will be called to fetch the token as a string. Mostly useful for debugging and testing.
+
 =head2 request ()
 
+Makes a request to Facebook to fetch an access token. Returns a L<Facebook::Graph::AccessToken::Response> object.
+
 =head1 LEGAL
 
 Facebook::Graph is Copyright 2010 Plain Black Corporation (L<http://www.plainblack.com>) and is licensed under the same terms as Perl itself.
